;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "easysession" "20251019.1621"
  "Persist and restore your sessions (desktop.el alternative)."
  '((emacs "25.1"))
  :url "https://github.com/jamescherti/easysession.el"
  :commit "e825ae668de678f85f49d01a1a9cde830ff65deb"
  :revdesc "e825ae668de6"
  :keywords '("convenience"))
